@@ -312,6 +312,10 @@ class Entry
     content, content_encoding = decode_content_encoding(page, log)
     log['content'] = AutoFile.new(uri, content, content_type)
 
+    if 1000000 < content.length
+      raise ArgumentError, "page too big (#{content.length}) : #{uri}"
+    end
+
     content_charset = @config.fetch('ForceCharset') {
       c = page.charset { nil }
       c = nil if c && !Mconv.valid_charset?(c)
@@ -450,7 +454,7 @@ class Entry
     t = tree.make_loc.filter {|e|
       path = e.path.sub(%r{^doc\(\)}, '')
       e = e.to_node
-      not (
+      not(
         (e.text? && (/\A\s*\z/ =~ e.to_s ||
                      ignore_text.any? {|pat| pat =~ e.to_s })) ||
         (e.elem? && (%r[\A(?:\{http://www.w3.org/1999/xhtml\})?style\z] =~ e.name ||
